==> alicloud_impinteraction_sdk-1.8.6.tar.gz: android/src/main/java/com/aliyun/imp/flutter/sdk/alicloud_impinteraction_sdk/plugin/FPOfLiverPusher.java <==
package com.aliyun.imp.flutter.sdk.alicloud_impinteraction_sdk.plugin;

import android.Manifest;
import android.app.Activity;
import android.os.Build;
import android.view.View;
import android.view.ViewGroup;

import androidx.annotation.NonNull;

import com.aliyun.imp.flutter.sdk.alicloud_impinteraction_sdk.CallbackAdapter;
import com.aliyun.imp.flutter.sdk.alicloud_impinteraction_sdk.FUtils;
import com.aliyun.imp.flutter.sdk.alicloud_impinteraction_sdk.ShowModeUtil;
import com.aliyun.imp.flutter.sdk.alicloud_impinteraction_sdk.beauty.LiveBeautyDelegate;
import com.aliyun.imp.flutter.sdk.alicloud_impinteraction_sdk.inner.Converter;
import com.aliyun.imp.flutter.sdk.alicloud_impinteraction_sdk.model.PusherOptions;
import com.aliyun.roompaas.base.exposable.Callback;
import com.aliyun.roompaas.base.util.PermissionHelper;
import com.aliyun.roompaas.base.util.Utils;
import com.aliyun.roompaas.live.AliLivePusherOptions;
import com.aliyun.roompaas.live.exposable.AliLiveMediaStreamOptions;
import com.aliyun.roompaas.live.exposable.LivePusherService;
import com.aliyun.roompaas.player.exposable.CanvasScale;

import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel.Result;

public class FPOfLiverPusher extends FPOfBaseLive {

    private static final int REQUEST_PERMISSION_OK = 1;
    public static final String[] PERMISSIONS_4_ANCHOR =
            Build.VERSION.SDK_INT > Build.VERSION_CODES.R ?
                    new String[]{Manifest.permission.CAMERA,
                            Manifest.permission.RECORD_AUDIO,
                            "android.permission.BLUETOOTH_CONNECT"} :
                    new String[]{Manifest.permission.CAMERA,
                            Manifest.permission.RECORD_AUDIO};

    private LivePusherService pusherService;

    private final PusherOptions pusherOptions = new PusherOptions();
    private boolean isPreviewed;
    private boolean isInLive;

    private LiveBeautyDelegate beautyDelegate;
    private Boolean beautyPanelShown = null;

    private interface API extends BaseLiveAPI {
        String startPreview = "startPreview";
        String toggleBeautyPanel = "toggleBeautyPanel";
        String startLive = "startLive";
        String setPreviewMode = "setPreviewMode";
        String switchCamera = "switchCamera";
        String setPreviewMirror = "setPreviewMirror";
        String setPushMirror = "setPushMirror";
        String stopLive = "stopLive";
    }

    @Override
    protected String getMethodChannelName() {
        return "alicloud_impinteraction_sdk_live_pusher";
    }

    @Override
    public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
        super.onMethodCall(call, result);
        switch (call.method) {
            case API.startPreview:
                startPreview(call, result);
                break;
            case API.toggleBeautyPanel:
                toggleBeautyPanel(call, result);
                break;
            case API.startLive:
                startLive(call, result);
                break;
            case API.setPreviewMode:
                setPreviewMode(call, result);
                break;
            case API.switchCamera:
                switchCamera(call, result);
                break;
            case API.setPreviewMirror:
                setPreviewMirror(call, result);
                break;
            case API.setPushMirror:
                setPushMirror(call, result);
                break;
            case API.stopLive:
                stopLive(call, result);
                break;
            case API.getLiveId:
                getLiveId(call, result);
                break;
            case API.getLiveDetail:
                getLiveDetail(call, result);
                break;
            default:
                result.notImplemented();
                break;
        }
    }

    public void startPreview(@NonNull MethodCall call, @NonNull Result result) {
        if (isPreviewed) {
            takeErr(result, " already in preview");
            return;
        }

        startPreviewCore(call, result);
    }

    public void toggleBeautyPanel(@NonNull MethodCall call, @NonNull Result result) {
        ViewGroup container = ofContainer();
        if (container != null) {
            if (beautyDelegate == null) {
                beautyDelegate = new LiveBeautyDelegate(container.getContext(), getLiveService());
            }
            if (!beautyPanelShown) {
                beautyDelegate.openPanel();
            } else {
                beautyDelegate.closePanel();
            }
            takeSuccess(result);
        } else {
            takeErr(result, "container null. please invoke after preview success");
        }
    }

    public void startLive(@NonNull MethodCall call, @NonNull Result result) {
        getPusherService().startLive(new CallbackAdapter<View>(call, result) {
            @Override
            public void onSuccess(View view) {
                super.onSuccess(view);
                isInLive = true;
            }
        });
    }

    public void setPreviewMode(@NonNull MethodCall call, @NonNull Result result) {
        int mode = parseInt(call, "mode", CanvasScale.Mode.ASPECT_FIT);
        getPusherService().setPreviewMode(mode);
        takeSuccess(result);
    }

    public void switchCamera(@NonNull MethodCall call, @NonNull Result result) {
        getPusherService().switchCamera();
        takeSuccess(result);
    }

    public void setPreviewMirror(@NonNull MethodCall call, @NonNull Result result) {
        getPusherService().setPreviewMirror(parseBool(call, "mirror"));
        takeSuccess(result);
    }

    public void setPushMirror(@NonNull MethodCall call, @NonNull Result result) {
        getPusherService().setPushMirror(parseBool(call, "mirror"));
        takeSuccess(result);
    }

    public void stopLive(@NonNull MethodCall call, @NonNull Result result) {
        isPreviewed = false;
        getPusherService().stopLive(new CallbackAdapter<Void>(call, result) {
            @Override
            public void onSuccess(Void unused) {
                super.onSuccess(unused);
                isInLive = false;
                beautyPanelShown = null;
            }
        });
    }

    private LivePusherService getPusherService() {
        if (pusherService == null) {
            AliLiveMediaStreamOptions mediaOptions = new AliLiveMediaStreamOptions();
            mediaOptions.videoBitrate = pusherOptions.videoBitrate;
            pusherOptions.resolution = PusherOptions.Resolution.VALUE_720P;
            mediaOptions.resolution = Converter.convert(pusherOptions.resolution);

            AliLivePusherOptions aliLivePusherOptions = new AliLivePusherOptions();
            aliLivePusherOptions.mediaStreamOptions = mediaOptions;

            pusherService = getLiveService().getPusherService(aliLivePusherOptions);
        }
        return pusherService;
    }

    private void startPreviewCore(@NonNull MethodCall call, @NonNull Result result) {
        Runnable startPreviewAction = () -> {
            LivePusherService pusherService = getPusherService();
            pusherOptions.showMode = ShowModeUtil.MODE_FILL;
            int previewMode = ShowModeUtil.getShowMode(pusherOptions.showMode);
            pusherService.setPreviewMode(previewMode);
            pusherService.startPreview(new Callback<View>() {
                @Override
                public void onSuccess(View view) {
                    ViewGroup container = ofContainer();
                    if (container != null) {
                        container.removeAllViews();
                        FUtils.addChildMatchParentSafely(container, view, new ViewGroup.LayoutParams(-1, -1));
                        isPreviewed = true;
                        beautyPanelShown = false;
                        takeSuccess(result);
                    } else {
                        takeGeneralErr(result, "container ref cleaned");
                    }
                }

                @Override
                public void onError(String s) {
                    takeErr(result, "startPreview onError: " + s);
                }
            });
        };

        Activity activity = Utils.getRef(activityRef);
        PermissionHelper permissionHelper = new PermissionHelper(activity, REQUEST_PERMISSION_OK, PERMISSIONS_4_ANCHOR);
        if (!permissionHelper.hasPermission()) {
            permissionHelper.setGrantedCallback(startPreviewAction);
            ActivityPluginBinding pluginBinding = Utils.getRef(actPluginBindingRef);
            if (pluginBinding != null) {
                pluginBinding.addRequestPermissionsResultListener((i, strings, ints) -> {
                    permissionHelper.handleRequestPermissionsResult(i, strings, ints);
                    return false;
                });
            } else {
                takeGeneralErr(result, "pluginBinding ref cleaned");
            }
            permissionHelper.requestPermissionIfVital();
        } else {
            startPreviewAction.run();
        }
    }

    @Override
    public void onResume() {
        super.onResume();
        if (isInLive) {
            getPusherService().resumeLive();
        }
    }

    @Override
    public void onPause() {
        super.onPause();
        if (isInLive) {
            getPusherService().pauseLive();
        }
    }

    @Override
    public void onStop() {
        super.onStop();
        // should not auto stop, user may want to keep this room and live
        // the live could not be restored after stop
    }

    @Override
    public void destroy() {
        super.destroy();
        pusherService = null;
        Utils.destroy(beautyDelegate);
    }
}

==> alicloud_impinteraction_sdk-1.8.15.tar.gz: android/src/main/java/com/aliyun/imp/flutter/sdk/alicloud_impinteraction_sdk/plugin/FPOfLiverPusher.java <==
package com.aliyun.imp.flutter.sdk.alicloud_impinteraction_sdk.plugin;

import android.Manifest;
import android.app.Activity;
import android.os.Build;
import android.view.View;
import android.view.ViewGroup;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;

import com.aliyun.imp.flutter.sdk.alicloud_impinteraction_sdk.CallbackAdapter;
import com.aliyun.imp.flutter.sdk.alicloud_impinteraction_sdk.FUtils;
import com.aliyun.imp.flutter.sdk.alicloud_impinteraction_sdk.ShowModeUtil;
import com.aliyun.imp.flutter.sdk.alicloud_impinteraction_sdk.beauty.LiveBeautyDelegate;
import com.aliyun.imp.flutter.sdk.alicloud_impinteraction_sdk.inner.Converter;
import com.aliyun.imp.flutter.sdk.alicloud_impinteraction_sdk.model.PusherOptions;
import com.aliyun.roompaas.base.exposable.Callback;
import com.aliyun.roompaas.base.util.PermissionHelper;
import com.aliyun.roompaas.base.util.Utils;
import com.aliyun.roompaas.live.AliLivePusherOptions;
import com.aliyun.roompaas.live.exposable.AliLiveMediaStreamOptions;
import com.aliyun.roompaas.live.exposable.LivePusherService;
import com.aliyun.roompaas.player.exposable.CanvasScale;

import java.util.Objects;

import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel.Result;

public class FPOfLiverPusher extends FPOfBaseLive {

    private static final int REQUEST_PERMISSION_OK = 1;
    public static final String[] PERMISSIONS_4_ANCHOR =
            Build.VERSION.SDK_INT > Build.VERSION_CODES.R ?
                    new String[]{Manifest.permission.CAMERA,
                            Manifest.permission.RECORD_AUDIO,
                            "android.permission.BLUETOOTH_CONNECT"} :
                    new String[]{Manifest.permission.CAMERA,
                            Manifest.permission.RECORD_AUDIO};

    private LivePusherService pusherService;

    private final PusherOptions pusherOptions = new PusherOptions();
    private final AliLiveMediaStreamOptions mediaOptions = new AliLiveMediaStreamOptions();
    private final AliLivePusherOptions aliLivePusherOptions = new AliLivePusherOptions();
    private boolean isPreviewed;
    private boolean isInLive;

    private LiveBeautyDelegate beautyDelegate;
    private Boolean beautyPanelShown = null;

    private interface API extends BaseLiveAPI {
        String startPreview = "startPreview";
        String toggleBeautyPanel = "toggleBeautyPanel";
        String startLive = "startLive";
        String setPreviewMode = "setPreviewMode";
        String switchCamera = "switchCamera";
        String setPreviewMirror = "setPreviewMirror";
        String setPushMirror = "setPushMirror";
        String stopLive = "stopLive";
    }

    @Override
    protected String getMethodChannelName() {
        return "alicloud_impinteraction_sdk_live_pusher";
    }

    @Override
    public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
        super.onMethodCall(call, result);
        switch (call.method) {
            case API.startPreview:
                startPreview(call, result);
                break;
            case API.toggleBeautyPanel:
                toggleBeautyPanel(call, result);
                break;
            case API.startLive:
                startLive(call, result);
                break;
            case API.setPreviewMode:
                setPreviewMode(call, result);
                break;
            case API.switchCamera:
                switchCamera(call, result);
                break;
            case API.setPreviewMirror:
                setPreviewMirror(call, result);
                break;
            case API.setPushMirror:
                setPushMirror(call, result);
                break;
            case API.stopLive:
                stopLive(call, result);
                break;
            case API.getLiveId:
                getLiveId(call, result);
                break;
            case API.getLiveDetail:
                getLiveDetail(call, result);
                break;
            default:
                result.notImplemented();
                break;
        }
    }

    public void startPreview(@NonNull MethodCall call, @NonNull Result result) {
        if (isPreviewed) {
            takeErr(result, " already in preview");
            return;
        }

        startPreviewCore(call, result);
    }

    public void toggleBeautyPanel(@NonNull MethodCall call, @NonNull Result result) {
        ViewGroup container = ofContainer();
        if (container != null) {
            if (beautyDelegate == null) {
                beautyDelegate = new LiveBeautyDelegate(container.getContext(), getLiveService());
            }
            if (!beautyPanelShown) {
                beautyDelegate.openPanel();
            } else {
                beautyDelegate.closePanel();
            }
            takeSuccess(result);
        } else {
            takeErr(result, "container null. please invoke after preview success");
        }
    }

    public void startLive(@NonNull MethodCall call, @NonNull Result result) {
        getPusherService().startLive(new CallbackAdapter<View>(call, result) {
            @Override
            public void onSuccess(View view) {
                super.onSuccess(view);
                isInLive = true;
            }
        });
    }

    public void setPreviewMode(@NonNull MethodCall call, @NonNull Result result) {
        int mode = parseInt(call, "mode", CanvasScale.Mode.ASPECT_FIT);
        getPusherService().setPreviewMode(mode);
        takeSuccess(result);
    }

    public void switchCamera(@NonNull MethodCall call, @NonNull Result result) {
        getPusherService().switchCamera();
        takeSuccess(result);
    }

    public void setPreviewMirror(@NonNull MethodCall call, @NonNull Result result) {
        getPusherService().setPreviewMirror(parseBool(call, "mirror"));
        takeSuccess(result);
    }

    public void setPushMirror(@NonNull MethodCall call, @NonNull Result result) {
        getPusherService().setPushMirror(parseBool(call, "mirror"));
        takeSuccess(result);
    }

    public void stopLive(@NonNull MethodCall call, @NonNull Result result) {
        isPreviewed = false;
        getPusherService().stopLive(new CallbackAdapter<Void>(call, result) {
            @Override
            public void onSuccess(Void unused) {
                super.onSuccess(unused);
                isInLive = false;
                beautyPanelShown = null;
            }
        });
    }

    private LivePusherService getPusherService() {
        mediaOptions.videoBitrate = pusherOptions.videoBitrate;
        if (pusherOptions.resolution == null) {
            pusherOptions.resolution = PusherOptions.Resolution.VALUE_720P;
        }
        mediaOptions.resolution = Converter.convert(pusherOptions.resolution);
        aliLivePusherOptions.mediaStreamOptions = mediaOptions;

        if (pusherService == null || !Objects.equals(pusherService, getLiveService().getPusherService(aliLivePusherOptions))) {
            pusherService = getLiveService().getPusherService(aliLivePusherOptions);
        }
        return pusherService;
    }

    private void startPreviewCore(@NonNull MethodCall call, @NonNull Result result) {
        pusherOptions.resolution = parseResolution(call);
        Runnable startPreviewAction = () -> {
            LivePusherService pusherService = getPusherService();
            pusherOptions.showMode = ShowModeUtil.MODE_FILL;
            int previewMode = ShowModeUtil.getShowMode(pusherOptions.showMode);
            pusherService.setPreviewMode(previewMode);
            pusherService.startPreview(new Callback<View>() {
                @Override
                public void onSuccess(View view) {
                    ViewGroup container = ofContainer();
                    if (container != null) {
                        container.removeAllViews();
                        FUtils.addChildMatchParentSafely(container, view, new ViewGroup.LayoutParams(-1, -1));
                        isPreviewed = true;
                        beautyPanelShown = false;
                        takeSuccess(result);
                    } else {
                        takeGeneralErr(result, "container ref cleaned");
                    }
                }

                @Override
                public void onError(String s) {
                    takeErr(result, "startPreview onError: " + s);
                }
            });
        };

        Activity activity = Utils.getRef(activityRef);
        PermissionHelper permissionHelper = new PermissionHelper(activity, REQUEST_PERMISSION_OK, PERMISSIONS_4_ANCHOR);
        if (!permissionHelper.hasPermission()) {
            permissionHelper.setGrantedCallback(startPreviewAction);
            ActivityPluginBinding pluginBinding = Utils.getRef(actPluginBindingRef);
            if (pluginBinding != null) {
                pluginBinding.addRequestPermissionsResultListener((i, strings, ints) -> {
                    permissionHelper.handleRequestPermissionsResult(i, strings, ints);
                    return false;
                });
            } else {
                takeGeneralErr(result, "pluginBinding ref cleaned");
            }
            permissionHelper.requestPermissionIfVital();
        } else {
            startPreviewAction.run();
        }
    }

    @Nullable
    private PusherOptions.Resolution parseResolution(@NonNull MethodCall call) {
        String resStr = parseString(call, "resolution");
        switch (resStr) {
            case "VALUE_480P":
                return PusherOptions.Resolution.VALUE_480P;
            case "VALUE_540P":
                return PusherOptions.Resolution.VALUE_540P;
            case "VALUE_720P":
                return PusherOptions.Resolution.VALUE_720P;
            default:
                return null;
        }
    }

    @Override
    public void onResume() {
        super.onResume();
        if (isInLive) {
            getPusherService().resumeLive();
        }
    }

    @Override
    public void onPause() {
        super.onPause();
        if (isInLive) {
            getPusherService().pauseLive();
        }
    }

    @Override
    public void onStop() {
        super.onStop();
        // should not auto stop, user may want to keep this room and live
        // the live could not be restored after stop
    }

    @Override
    public void destroy() {
        super.destroy();
        pusherService = null;
        Utils.destroy(beautyDelegate);
    }
}
